==> qtjambi-qt3dinput-debuginfo-linux-x64-5.15.18.jar: sources/QtJambi3DInput/QAbstractPhysicalDevice_shell.h <==
#ifndef QABSTRACTPHYSICALDEVICE_SHELL_H
#define QABSTRACTPHYSICALDEVICE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <Qt3DInput/qabstractphysicaldevice.h>
#include <QtJambi/QtJambiAPI>
#include <Qt3DCore/qnode.h>
#include <Qt3DCore/qnodecommand.h>
#include <Qt3DCore/qnodecreatedchange.h>
#include <Qt3DCore/qnodeid.h>
#include <Qt3DCore/qscenechange.h>
#include <Qt3DInput/qaxissetting.h>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QAbstractPhysicalDevice_shell : public Qt3DInput::QAbstractPhysicalDevice, public QtJambiShellInterface
{
public:
    QAbstractPhysicalDevice_shell(Qt3DCore::QNode* parent0 = nullptr);
    ~QAbstractPhysicalDevice_shell() override;

    int axisCount() const override;
    int axisIdentifier(const QString& name0) const override;
    QStringList axisNames() const override;
    int buttonCount() const override;
    int buttonIdentifier(const QString& name0) const override;
    QStringList buttonNames() const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QSharedPointer<Qt3DCore::QNodeCreatedChangeBase> createNodeCreationChange() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void sceneChangeEvent(const QSharedPointer<Qt3DCore::QSceneChange>& change0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractPhysicalDevice_access : public Qt3DInput::QAbstractPhysicalDevice
{
    jint __qt_axisCount(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_axisIdentifier_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0) const;
    jobject __qt_axisNames(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_buttonCount(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_buttonIdentifier_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0) const;
    jobject __qt_buttonNames(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_createNodeCreationChange(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QABSTRACTPHYSICALDEVICE_SHELL_H

==> qtjambi-qt3dinput-debuginfo-linux-x64-6.5.5.jar: sources/QtJambi3DInput/QAbstractPhysicalDevice_shell.h <==
#ifndef QABSTRACTPHYSICALDEVICE_SHELL_H
#define QABSTRACTPHYSICALDEVICE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <Qt3DInput/qabstractphysicaldevice.h>
#include <QtJambi/QtJambiAPI>
#include <Qt3DCore/qnode.h>
#include <Qt3DCore/qnodeid.h>
#include <Qt3DInput/qaxissetting.h>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QAbstractPhysicalDevice_shell : public Qt3DInput::QAbstractPhysicalDevice, public QtJambiShellInterface
{
public:
    QAbstractPhysicalDevice_shell(Qt3DCore::QNode* parent0 = nullptr);
    ~QAbstractPhysicalDevice_shell() override;

    int axisCount() const override;
    int axisIdentifier(const QString& name0) const override;
    QStringList axisNames() const override;
    int buttonCount() const override;
    int buttonIdentifier(const QString& name0) const override;
    QStringList buttonNames() const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractPhysicalDevice_access : public Qt3DInput::QAbstractPhysicalDevice
{
    jint __qt_axisCount_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_axisIdentifier_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0) const;
    jobject __qt_axisNames_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_buttonCount_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_buttonIdentifier_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0) const;
    jobject __qt_buttonNames_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QABSTRACTPHYSICALDEVICE_SHELL_H
